@@ -3,7 +3,7 @@ import json
 import psycopg2
 from psycopg2.extras import RealDictCursor
 import pymysql
-
+import os
 from botocore.exceptions import ClientError
 from harbour.database.table import Table
 
@@ -31,7 +31,7 @@ class Database:
 
             # Requests secrets manager for the credentials
             response = self.client.get_secret_value(
-                SecretId="{}/{}/{}".format(self.engine, self.alias, self.user))
+                SecretId=os.environ.get('SECRETS') or "{}/{}/{}".format(self.engine, self.alias, self.user))
 
         except ClientError as exc:
 
@@ -66,6 +66,7 @@ class Database:
                 'password': secret['password'],
                 'dbname': secret['dbname'],
                 'port': int(secret['port']),
+                'init_command': secret.get('init_command')
             }
 
             # Sets the SSDictCursor from MySQL connections
@@ -84,6 +85,14 @@ class Database:
             ) if self.engine == 'mysql' else self.conn.cursor(
                 cursor_factory=RealDictCursor)
 
+            # case exists init_commands to execute before
+            if secret.get('init_command'):
+                n = secret['init_command'].split(';')
+                for x in n:
+                    if x:
+                        self.curs.execute(x)
+                        self.conn.commit()
+
             return self.conn, self.curs
 
     def table(self, table, *args, **kwargs):
