@@ -8,7 +8,7 @@ class Table:
         # Default state
         self.sql = None
         self.columns = '*'
-        self.filters = {}
+        self.filter = None
         self._limit = None
         self.order = None
         self.primary_key = None
@@ -51,15 +51,18 @@ class Table:
 
         return self
 
-    def where(self, *filters):
+    def where(self, filter:str):
         """Appends a where clausule to the query.
         Premisses:
-            lists are converted to IN() statements.
-            strings and ints are converted to = statements.
+            This filter is only a string 
         """
 
-        for f in filters:
-            self.filters.update(f)
+        if filter is not None:
+            if "where " in filter.lower():
+                filter = filter.replace("where ", "")
+            if filter[:3].lower() == "and":
+                filter = filter[3:]
+        self.filter = filter
 
         return self
 
@@ -78,7 +81,7 @@ class Table:
     def build(self, *args, **kwargs):
         """Builds the SQL"""
 
-        self.sql = "/*Application: Tethys*/\n"
+        self.sql = "/*Application: Tethys - Dumper*/\n"
         self.sql += "SELECT {}".format(', '.join(self.columns))
 
         if self.db.engine == 'postgresql':
@@ -88,23 +91,9 @@ class Table:
             self.sql += ", CAST(UNIX_TIMESTAMP() * POW(10, 6) AS DECIMAL(25,9)) AS _sequence\n"
             self.sql += "FROM `{}`.{}\n".format(self.schema, self.name)
 
-        if self.filters != {}:
+        if self.filter is not None:
 
-            self.sql += "WHERE\n\t1=1\n"
-
-            for c, f in self.filters.items():
-
-                if isinstance(f, list):
-
-                    self.sql += "\tAND {} IN({})\n".format(
-                        c, ','.join([repr(v) for v in f]))
-
-                if isinstance(f, (
-                        str,
-                        int,
-                )):
-
-                    self.sql += "\tAND {} = {}\n".format(c, repr(f))
+            self.sql += "WHERE\n\t1=1 AND {}\n".format(self.filter)
 
         if self.order is not None:
 
